@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: bjm.c,v 1.12 2004/09/04 03:39:20 roland Exp $
+ *	$Id: bjm.c,v 1.15 2005/06/01 19:02:37 roland Exp $
  */
 #include "defs.h"
 
@@ -42,7 +42,6 @@
 #include <sys/user.h>
 #include <sys/syscall.h>
 #include <signal.h>
-#include <linux/linkage.h>
 
 /* Bits of module.flags.  */
 
@@ -119,7 +118,7 @@ struct tcb *tcp;
 			size_t			ret;
 			umove(tcp, tcp->u_arg[2], &mi);
 			tprintf("{address=%#lx, size=%lu, flags=", mi.addr, mi.size);
-			printflags(modflags, mi.flags);
+			printflags(modflags, mi.flags, "MOD_???");
 			tprintf(", usecount=%lu}", mi.usecount);
 			umove(tcp, tcp->u_arg[4], &ret);
 			tprintf(", %Zu", ret);
@@ -136,7 +135,7 @@ struct tcb *tcp;
 				size_t	idx;
 
 				if (data==NULL) {
-					fprintf(stderr, "sys_query_module: No memory\n");
+					fprintf(stderr, "out of memory\n");
 					tprintf(" /* %Zu entries */ ", ret);
 				} else {
 					umoven(tcp, tcp->u_arg[2], tcp->u_arg[3], data);
@@ -161,7 +160,7 @@ struct tcb *tcp;
 				size_t			idx;
 
 				if (data==NULL) {
-					fprintf(stderr, "sys_query_module: No memory\n");
+					fprintf(stderr, "out of memory\n");
 					tprintf(" /* %Zu entries */ ", ret);
 				} else {
 					umoven(tcp, tcp->u_arg[2], tcp->u_arg[3], data);
