@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.13 2004/10/19 23:23:59 roland Exp $
+ *	$Id: syscallent.h,v 1.15 2005/05/09 08:02:05 roland Exp $
  */
 
 	{ 6,	0,	printargs,		"osf_syscall"		}, /* 0, not implemented */
@@ -55,12 +55,12 @@
 	{ 0,	0,	sys_getuid,		"getxuid"		}, /* 24 */
 	{ 5,	0,	printargs,		"exec_with_loader"	}, /* 25, not implemented */
 	{ 4,	0,	sys_ptrace,		"ptrace"		}, /* 26 */
-	{ 5,	0,	printargs,		"osf_nrecmsg"		}, /* 27, not implemented */
+	{ 5,	0,	printargs,		"osf_nrecvmsg"		}, /* 27, not implemented */
 	{ 5,	0,	printargs,		"osf_nsendmsg"		}, /* 28, not implemented */
 	{ 5,	0,	printargs,		"osf_nrecvfrom"		}, /* 29, not implemented */
 	{ 5,	0,	printargs,		"osf_naccept"		}, /* 30, not implemented */
 	{ 5,	0,	printargs,		"osf_ngetpeername"	}, /* 31, not implemented */
-	{ 5,	0,	printargs,		"osf_ngetsocketname"	}, /* 32, not implemented */
+	{ 5,	0,	printargs,		"osf_ngetsockname"	}, /* 32, not implemented */
 	{ 2,	TF,	sys_access,		"access"		}, /* 33 */
 	{ 5,	0,	printargs,		"osf_chflags"		}, /* 34, not implemented */
 	{ 5,	0,	printargs,		"osf_fchflags"		}, /* 35, not implemented */
@@ -426,11 +426,11 @@
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"	}, /* 395 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"	}, /* 396 */
 	{ 5,	0,	printargs,		"tuxcall"		}, /* 397 */
-	{ 2,	0,	printargs,		"io_setup"		}, /* 398 */
-	{ 1,	0,	printargs,		"io_destroy"		}, /* 399 */
-	{ 5,	0,	printargs,		"io_getevents"		}, /* 400 */
-	{ 3,	0,	printargs,		"io_submit"		}, /* 401 */
-	{ 3,	0,	printargs,		"io_cancel"		}, /* 402 */
+	{ 2,	0,	sys_io_setup,		"io_setup"		}, /* 398 */
+	{ 1,	0,	sys_io_destroy,		"io_destroy"		}, /* 399 */
+	{ 5,	0,	sys_io_getevents,		"io_getevents"		}, /* 400 */
+	{ 3,	0,	sys_io_submit,		"io_submit"		}, /* 401 */
+	{ 3,	0,	sys_io_cancel,		"io_cancel"		}, /* 402 */
 	{ 5,	0,	printargs,		"SYS_403"		}, /* 403 */
 	{ 5,	0,	printargs,		"SYS_404"		}, /* 404 */
 	{ 1,	TP,	sys_exit,		"exit_group"		}, /* 405 */
@@ -454,8 +454,8 @@
 	{ 5,	TI,	sys_semtimedop,		"semtimedop"		}, /* 423 */
 	{ 3,	TS,	sys_tgkill,		"tgkill"		}, /* 424 */
 	{ 2,	TF,	sys_stat64,		"stat64"		}, /* 425 */
-	{ 2,	0,	sys_fstat64,		"fstat64"		}, /* 426 */
-	{ 2,	TF,	sys_lstat64,		"lstat64"		}, /* 427 */
+	{ 2,	TF,	sys_lstat64,		"lstat64"		}, /* 426 */
+	{ 2,	0,	sys_fstat64,		"fstat64"		}, /* 427 */
 	{ 5,	0,	printargs,		"vserver"		}, /* 428 ??? */
 	{ 5,	0,	printargs,		"mbind"			}, /* 429 ??? */
 	{ 5,	0,	printargs,		"get_mempolicy"		}, /* 430 ??? */
