@@ -270,11 +270,11 @@
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity" },/* 240 */
 	{ -1,	0,	printargs,		"SYS_241"	}, /* 241 */
 	{ -1,	0,	printargs,		"SYS_242"	}, /* 242 */
-	{ 2,	0,	printargs,		"io_setup"	}, /* 243 */
-	{ 1,	0,	printargs,		"io_destroy"	}, /* 244 */
-	{ 5,	0,	printargs,		"io_getevents"	}, /* 245 */
-	{ 3,	0,	printargs,		"io_submit"	}, /* 246 */
-	{ 3,	0,	printargs,		"io_cancel"	}, /* 247 */
+	{ 2,	0,	sys_io_setup,		"io_setup"	}, /* 243 */
+	{ 1,	0,	sys_io_destroy,		"io_destroy"	}, /* 244 */
+	{ 5,	0,	sys_io_getevents,		"io_getevents"	}, /* 245 */
+	{ 3,	0,	sys_io_submit,		"io_submit"	}, /* 246 */
+	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 247 */
 	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 248 */
 	{ 1,	0,	sys_epoll_create,	"epoll_create"	}, /* 249 */
 	{ 4,	0,	sys_epoll_ctl,		"epoll_ctl"	}, /* 250 */
