@@ -34,7 +34,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.90 2004/10/19 23:33:47 roland Exp $
+ *	$Id: process.c,v 1.97 2005/06/08 20:45:28 roland Exp $
  */
 
 #include "defs.h"
@@ -220,7 +220,7 @@ static const struct xlat prctl_options[] = {
 };
 
 
-const char *
+static const char *
 unalignctl_string (unsigned int ctl)
 {
 	static char buf[16];
@@ -396,7 +396,7 @@ struct tcb *tcp;
 				tcp->flags |= TCB_GROUP_EXITING;
 		} else
 # endif
-		if (tcp->scno == __NR_exit_group)
+		if (known_scno(tcp) == __NR_exit_group)
 			tcp->flags |= TCB_GROUP_EXITING;
 #endif
 	}
@@ -463,7 +463,7 @@ struct tcb *tcp;
 
 	if (exiting(tcp)) {
 #ifdef SYS_rfork
-		if (tcp->scno == SYS_rfork && !(tcp->u_arg[0]&RFPROC))
+		if (known_scno(tcp) == SYS_rfork && !(tcp->u_arg[0]&RFPROC))
 			return 0;
 #endif
 		if (getrval2(tcp))
@@ -542,10 +542,10 @@ extern void print_ldt_entry();
 # if defined IA64
 #  define ARG_FLAGS	0
 #  define ARG_STACK	1
-#  define ARG_STACKSIZE	(tcp->scno == SYS_clone2 ? 2 : -1)
-#  define ARG_PTID	(tcp->scno == SYS_clone2 ? 3 : 2)
-#  define ARG_CTID	(tcp->scno == SYS_clone2 ? 4 : 3)
-#  define ARG_TLS	(tcp->scno == SYS_clone2 ? 5 : 4)
+#  define ARG_STACKSIZE	(known_scno(tcp) == SYS_clone2 ? 2 : -1)
+#  define ARG_PTID	(known_scno(tcp) == SYS_clone2 ? 3 : 2)
+#  define ARG_CTID	(known_scno(tcp) == SYS_clone2 ? 4 : 3)
+#  define ARG_TLS	(known_scno(tcp) == SYS_clone2 ? 5 : 4)
 # elif defined S390 || defined S390X
 #  define ARG_STACK	0
 #  define ARG_FLAGS	1
@@ -579,8 +579,7 @@ struct tcb *tcp;
 				tcp->u_arg[ARG_STACKSIZE]);
 # endif
 		tprintf("flags=");
-		if (printflags(clone_flags, flags &~ CSIGNAL) == 0)
-			tprintf("0");
+		printflags(clone_flags, flags &~ CSIGNAL, NULL);
 		if ((flags & CSIGNAL) != 0)
 			tprintf("|%s", signame(flags & CSIGNAL));
 		if ((flags & (CLONE_PARENT_SETTID|CLONE_CHILD_SETTID
@@ -702,6 +701,7 @@ int new;
 	return -1;
 }
 
+#if 0
 int
 setarg(tcp, argnum)
 	struct tcb *tcp;
@@ -779,6 +779,7 @@ setarg(tcp, argnum)
 #endif
 	return 0;
 }
+#endif
 
 #if defined SYS_clone || defined SYS_clone2
 int
@@ -932,7 +933,7 @@ struct tcb *tcp;
 	int dont_follow = 0;
 
 #ifdef SYS_vfork
-	if (tcp->scno == SYS_vfork) {
+	if (known_scno(tcp) == SYS_vfork) {
 		/* Attempt to make vfork into fork, which we can follow. */
 		if (!followvfork ||
 		    change_syscall(tcp, SYS_fork) < 0)
@@ -1226,34 +1227,53 @@ int
 sys_setgroups(tcp)
 struct tcb *tcp;
 {
-	int i, len;
-	GETGROUPS_T *gidset;
-
 	if (entering(tcp)) {
+		unsigned long len, size, start, cur, end, abbrev_end;
+		GETGROUPS_T gid;
+		int failed = 0;
+
 		len = tcp->u_arg[0];
-		tprintf("%u, ", len);
-		if (len <= 0) {
+		tprintf("%lu, ", len);
+		if (len == 0) {
 			tprintf("[]");
 			return 0;
 		}
-		gidset = (GETGROUPS_T *) malloc(len * sizeof(GETGROUPS_T));
-		if (gidset == NULL) {
-			fprintf(stderr, "sys_setgroups: out of memory\n");
-			return -1;
+		start = tcp->u_arg[1];
+		if (start == 0) {
+			tprintf("NULL");
+			return 0;
 		}
-		if (!verbose(tcp))
-			tprintf("%#lx", tcp->u_arg[1]);
-		else if (umoven(tcp, tcp->u_arg[1],
-		    len * sizeof(GETGROUPS_T), (char *) gidset) < 0)
-			tprintf("[?]");
-		else {
-			tprintf("[");
-			for (i = 0; i < len; i++)
-				tprintf("%s%lu", i ? ", " : "",
-					(unsigned long) gidset[i]);
-			tprintf("]");
+		size = len * sizeof(gid);
+		end = start + size;
+		if (!verbose(tcp) || size / sizeof(gid) != len || end < start) {
+			tprintf("%#lx", start);
+			return 0;
 		}
-		free((char *) gidset);
+		if (abbrev(tcp)) {
+			abbrev_end = start + max_strlen * sizeof(gid);
+			if (abbrev_end < start)
+				abbrev_end = end;
+		} else {
+			abbrev_end = end;
+		}
+		tprintf("[");
+		for (cur = start; cur < end; cur += sizeof(gid)) {
+			if (cur > start)
+				tprintf(", ");
+			if (cur >= abbrev_end) {
+				tprintf("...");
+				break;
+			}
+			if (umoven(tcp, cur, sizeof(gid), (char *) &gid) < 0) {
+				tprintf("?");
+				failed = 1;
+				break;
+			}
+			tprintf("%lu", (unsigned long) gid);
+		}
+		tprintf("]");
+		if (failed)
+			tprintf(" %#lx", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1262,38 +1282,62 @@ int
 sys_getgroups(tcp)
 struct tcb *tcp;
 {
-	int i, len;
-	GETGROUPS_T *gidset;
+	unsigned long len;
 
 	if (entering(tcp)) {
 		len = tcp->u_arg[0];
-		tprintf("%u, ", len);
+		tprintf("%lu, ", len);
 	} else {
+		unsigned long size, start, cur, end, abbrev_end;
+		GETGROUPS_T gid;
+		int failed = 0;
+
 		len = tcp->u_rval;
-		if (len <= 0) {
+		if (len == 0) {
 			tprintf("[]");
 			return 0;
 		}
-		gidset = (GETGROUPS_T *) malloc(len * sizeof(GETGROUPS_T));
-		if (gidset == NULL) {
-			fprintf(stderr, "sys_getgroups: out of memory\n");
-			return -1;
-		}
-		if (!tcp->u_arg[1])
+		start = tcp->u_arg[1];
+		if (start == 0) {
 			tprintf("NULL");
-		else if (!verbose(tcp) || tcp->u_arg[0] == 0)
-			tprintf("%#lx", tcp->u_arg[1]);
-		else if (umoven(tcp, tcp->u_arg[1],
-		    len * sizeof(GETGROUPS_T), (char *) gidset) < 0)
-			tprintf("[?]");
-		else {
-			tprintf("[");
-			for (i = 0; i < len; i++)
-				tprintf("%s%lu", i ? ", " : "",
-					(unsigned long) gidset[i]);
-			tprintf("]");
+			return 0;
 		}
-		free((char *)gidset);
+		if (tcp->u_arg[0] == 0) {
+			tprintf("%#lx", start);
+			return 0;
+		}
+		size = len * sizeof(gid);
+		end = start + size;
+		if (!verbose(tcp) || tcp->u_arg[0] == 0 ||
+		    size / sizeof(gid) != len || end < start) {
+			tprintf("%#lx", start);
+			return 0;
+		}
+		if (abbrev(tcp)) {
+			abbrev_end = start + max_strlen * sizeof(gid);
+			if (abbrev_end < start)
+				abbrev_end = end;
+		} else {
+			abbrev_end = end;
+		}
+		tprintf("[");
+		for (cur = start; cur < end; cur += sizeof(gid)) {
+			if (cur > start)
+				tprintf(", ");
+			if (cur >= abbrev_end) {
+				tprintf("...");
+				break;
+			}
+			if (umoven(tcp, cur, sizeof(gid), (char *) &gid) < 0) {
+				tprintf("?");
+				failed = 1;
+				break;
+			}
+			tprintf("%lu", (unsigned long) gid);
+		}
+		tprintf("]");
+		if (failed)
+			tprintf(" %#lx", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1303,34 +1347,53 @@ int
 sys_setgroups32(tcp)
 struct tcb *tcp;
 {
-	int i, len;
-	GETGROUPS32_T *gidset;
-
 	if (entering(tcp)) {
+		unsigned long len, size, start, cur, end, abbrev_end;
+		GETGROUPS32_T gid;
+		int failed = 0;
+
 		len = tcp->u_arg[0];
-		tprintf("%u, ", len);
-		if (len <= 0) {
+		tprintf("%lu, ", len);
+		if (len == 0) {
 			tprintf("[]");
 			return 0;
 		}
-		gidset = (GETGROUPS32_T *) malloc(len * sizeof(GETGROUPS32_T));
-		if (gidset == NULL) {
-			fprintf(stderr, "sys_setgroups32: out of memory\n");
-			return -1;
+		start = tcp->u_arg[1];
+		if (start == 0) {
+			tprintf("NULL");
+			return 0;
 		}
-		if (!verbose(tcp))
-			tprintf("%#lx", tcp->u_arg[1]);
-		else if (umoven(tcp, tcp->u_arg[1],
-		    len * sizeof(GETGROUPS32_T), (char *) gidset) < 0)
-			tprintf("[?]");
-		else {
-			tprintf("[");
-			for (i = 0; i < len; i++)
-				tprintf("%s%lu", i ? ", " : "",
-					(unsigned long) gidset[i]);
-			tprintf("]");
+		size = len * sizeof(gid);
+		end = start + size;
+		if (!verbose(tcp) || size / sizeof(gid) != len || end < start) {
+			tprintf("%#lx", start);
+			return 0;
 		}
-		free((char *) gidset);
+		if (abbrev(tcp)) {
+			abbrev_end = start + max_strlen * sizeof(gid);
+			if (abbrev_end < start)
+				abbrev_end = end;
+		} else {
+			abbrev_end = end;
+		}
+		tprintf("[");
+		for (cur = start; cur < end; cur += sizeof(gid)) {
+			if (cur > start)
+				tprintf(", ");
+			if (cur >= abbrev_end) {
+				tprintf("...");
+				break;
+			}
+			if (umoven(tcp, cur, sizeof(gid), (char *) &gid) < 0) {
+				tprintf("?");
+				failed = 1;
+				break;
+			}
+			tprintf("%lu", (unsigned long) gid);
+		}
+		tprintf("]");
+		if (failed)
+			tprintf(" %#lx", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1339,38 +1402,58 @@ int
 sys_getgroups32(tcp)
 struct tcb *tcp;
 {
-	int i, len;
-	GETGROUPS32_T *gidset;
+	unsigned long len;
 
 	if (entering(tcp)) {
 		len = tcp->u_arg[0];
-		tprintf("%u, ", len);
+		tprintf("%lu, ", len);
 	} else {
+		unsigned long size, start, cur, end, abbrev_end;
+		GETGROUPS32_T gid;
+		int failed = 0;
+
 		len = tcp->u_rval;
-		if (len <= 0) {
+		if (len == 0) {
 			tprintf("[]");
 			return 0;
 		}
-		gidset = (GETGROUPS32_T *) malloc(len * sizeof(GETGROUPS32_T));
-		if (gidset == NULL) {
-			fprintf(stderr, "sys_getgroups32: out of memory\n");
-			return -1;
-		}
-		if (!tcp->u_arg[1])
+		start = tcp->u_arg[1];
+		if (start == 0) {
 			tprintf("NULL");
-		else if (!verbose(tcp) || tcp->u_arg[0] == 0)
-			tprintf("%#lx", tcp->u_arg[1]);
-		else if (umoven(tcp, tcp->u_arg[1],
-		    len * sizeof(GETGROUPS32_T), (char *) gidset) < 0)
-			tprintf("[?]");
-		else {
-			tprintf("[");
-			for (i = 0; i < len; i++)
-				tprintf("%s%lu", i ? ", " : "",
-					(unsigned long) gidset[i]);
-			tprintf("]");
+			return 0;
 		}
-		free((char *)gidset);
+		size = len * sizeof(gid);
+		end = start + size;
+		if (!verbose(tcp) || tcp->u_arg[0] == 0 ||
+		    size / sizeof(gid) != len || end < start) {
+			tprintf("%#lx", start);
+			return 0;
+		}
+		if (abbrev(tcp)) {
+			abbrev_end = start + max_strlen * sizeof(gid);
+			if (abbrev_end < start)
+				abbrev_end = end;
+		} else {
+			abbrev_end = end;
+		}
+		tprintf("[");
+		for (cur = start; cur < end; cur += sizeof(gid)) {
+			if (cur > start)
+				tprintf(", ");
+			if (cur >= abbrev_end) {
+				tprintf("...");
+				break;
+			}
+			if (umoven(tcp, cur, sizeof(gid), (char *) &gid) < 0) {
+				tprintf("?");
+				failed = 1;
+				break;
+			}
+			tprintf("%lu", (unsigned long) gid);
+		}
+		tprintf("]");
+		if (failed)
+			tprintf(" %#lx", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1575,39 +1658,6 @@ struct tcb *tcp;
 #endif
 
 
-void
-fake_execve(tcp, program, argv, envp)
-struct tcb *tcp;
-char *program;
-char *argv[];
-char *envp[];
-{
-	int i;
-
-#ifdef ARM
-	if (!(qual_flags[SYS_execve - __NR_SYSCALL_BASE] & QUAL_TRACE))
-		return;
-#else
-	if (!(qual_flags[SYS_execve] & QUAL_TRACE))
-		return;
-#endif /* !ARM */
-	printleader(tcp);
-	tprintf("execve(");
-	string_quote(program);
-	tprintf(", [");
-	for (i = 0; argv[i] != NULL; i++) {
-		if (i != 0)
-			tprintf(", ");
-		string_quote(argv[i]);
-	}
-	for (i = 0; envp[i] != NULL; i++)
-		;
-	tprintf("], [/* %d var%s */]) ", i, (i != 1) ? "s" : "");
-	tabto(acolumn);
-	tprintf("= 0");
-	printtrailer(tcp);
-}
-
 static void
 printargv(tcp, addr)
 struct tcb *tcp;
@@ -1853,8 +1903,7 @@ int bitness;
 			exited = printstatus(status);
 		/* options */
 		tprintf(", ");
-		if (!printflags(wait4_options, tcp->u_arg[2]))
-			tprintf("0");
+		printflags(wait4_options, tcp->u_arg[2], "W???");
 		if (n == 4) {
 			tprintf(", ");
 			/* usage */
@@ -2078,8 +2127,7 @@ struct tcb *tcp;
 			printsiginfo(&si, verbose (tcp));
 		/* options */
 		tprintf(", ");
-		if (!printflags(wait4_options, tcp->u_arg[3]))
-			tprintf("0");
+		printflags(wait4_options, tcp->u_arg[3], "W???");
 		if (tcp->u_nargs > 4) {
 			/* usage */
 			tprintf(", ");
@@ -2171,6 +2219,12 @@ static const struct xlat ptrace_cmds[] = {
 #ifdef PTRACE_SETFPXREGS
 	{ PTRACE_SETFPXREGS,	"PTRACE_SETFPXREGS",	},
 #endif
+#ifdef PTRACE_GETVRREGS
+	{ PTRACE_GETVRREGS,	"PTRACE_GETVRREGS",	},
+#endif
+#ifdef PTRACE_SETVRREGS
+	{ PTRACE_SETVRREGS,	"PTRACE_SETVRREGS",	},
+#endif
 #ifdef SUNOS4
 	{ PTRACE_READDATA,	"PTRACE_READDATA"	},
 	{ PTRACE_WRITEDATA,	"PTRACE_WRITEDATA"	},
@@ -2535,33 +2589,33 @@ const struct xlat struct_user_offsets[] = {
 	{ 4*SS,			"4*SS"					},
 #else /* !I386 */
 #ifdef X86_64
-	{ 8*RDI,		"8*RDI"					},
-	{ 8*RSI,		"8*RSI"					},
-	{ 8*RDX,		"8*RDX"					},
-	{ 8*R10, 		"8*R10" },
-	{ 8*R8, 		"8*R8" },
-	{ 8*R9, 		"8*R9" },
-	{ 8*RBX,		"8*RBX"					},
-	{ 8*RCX,		"8*RCX"					},
+	{ 8*R15, 		"8*R15"					},
+	{ 8*R14, 		"8*R14"					},
+	{ 8*R13, 		"8*R13"					},
+	{ 8*R12, 		"8*R12"					},
 	{ 8*RBP,		"8*RBP"					},
+	{ 8*RBX,		"8*RBX"					},
+	{ 8*R11,		"8*R11"					},
+	{ 8*R10,		"8*R10"					},
+	{ 8*R9,			"8*R9"					},
+	{ 8*R8,			"8*R8"					},
 	{ 8*RAX,		"8*RAX"					},
+	{ 8*RCX,		"8*RCX"					},
+	{ 8*RDX,		"8*RDX"					},
+	{ 8*RSI,		"8*RSI"					},
+	{ 8*RDI,		"8*RDI"					},
 #if 0
-	{ 8*DS,			"8*DS"					},
-	{ 8*ES,			"8*ES"					},
-	{ 8*FS,			"8*FS"					},
-	{ 8*GS,			"8*GS"					},
+	{ DS,			"DS"					},
+	{ ES,			"ES"					},
+	{ FS,			"FS"					},
+	{ GS,			"GS"					},
 #endif
-	{ 8*ORIG_RAX,		"8*ORIG_EAX"				},
+	{ 8*ORIG_RAX,		"8*ORIG_RAX"				},
 	{ 8*RIP,		"8*RIP"					},
 	{ 8*CS,			"8*CS"					},
 	{ 8*EFLAGS,		"8*EFL"					},
-	{ 8*RSP,		"8*RSP"				},
+	{ 8*RSP,		"8*RSP"					},
 	{ 8*SS,			"8*SS"					},
-	{ 8*R11, 		"8*R11" },
-	{ 8*R12, 		"8*R12" },
-	{ 8*R13, 		"8*R13" },
-	{ 8*R14, 		"8*R14" },
-	{ 8*R15, 		"8*R15" },
 #endif
 #ifdef M68K
 	{ 4*PT_D1,		"4*PT_D1"				},
@@ -3096,7 +3150,7 @@ struct tcb *tcp;
 	tprintf("%d, ", (int) tcp->u_arg[0]);
 	printxval(schedulers, tcp->u_arg[1], "SCHED_???");
 	if (umove(tcp, tcp->u_arg[2], &p) < 0)
-	    tprintf(", %lx", tcp->u_arg[2]);
+	    tprintf(", %#lx", tcp->u_arg[2]);
 	else
 	    tprintf(", { %d }", p.__sched_priority);
     }
@@ -3112,7 +3166,7 @@ struct tcb *tcp;
     } else {
 	struct sched_param p;
 	if (umove(tcp, tcp->u_arg[1], &p) < 0)
-	    tprintf("%lx", tcp->u_arg[1]);
+	    tprintf("%#lx", tcp->u_arg[1]);
 	else
 	    tprintf("{ %d }", p.__sched_priority);
     }
@@ -3126,7 +3180,7 @@ struct tcb *tcp;
     if (entering(tcp)) {
 	struct sched_param p;
 	if (umove(tcp, tcp->u_arg[1], &p) < 0)
-	    tprintf("%d, %lx", (int) tcp->u_arg[0], tcp->u_arg[1]);
+	    tprintf("%d, %#lx", (int) tcp->u_arg[0], tcp->u_arg[1]);
 	else
 	    tprintf("%d, { %d }", (int) tcp->u_arg[0], p.__sched_priority);
     }
@@ -3142,4 +3196,39 @@ struct tcb *tcp;
     }
     return 0;
 }
+
+#ifdef X86_64
+#include <asm/prctl.h>
+
+static const struct xlat archvals[] = {
+	{ ARCH_SET_GS,		"ARCH_SET_GS"		},
+	{ ARCH_SET_FS,		"ARCH_SET_FS"		},
+	{ ARCH_GET_FS,		"ARCH_GET_FS"		},
+	{ ARCH_GET_GS,		"ARCH_GET_GS"		},
+	{ 0,			NULL			},
+};
+
+int
+sys_arch_prctl(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	printxval(archvals, tcp->u_arg[0], "ARCH_???");
+	if (tcp->u_arg[0] == ARCH_SET_GS
+	    || tcp->u_arg[0] == ARCH_SET_FS)
+	    tprintf(", %#lx", tcp->u_arg[1]);
+    } else {
+	if (tcp->u_arg[0] == ARCH_GET_GS
+	    || tcp->u_arg[0] == ARCH_GET_FS) {
+	    long int v;
+	    if (!syserror(tcp) && umove(tcp, tcp->u_arg[1], &v) != -1)
+		tprintf(", [%#lx]", v);
+	    else
+		tprintf(", %#lx", tcp->u_arg[1]);
+	}
+    }
+    return 0;
+}
+#endif
+
 #endif
