@@ -27,12 +27,12 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: strace.c,v 1.60 2004/10/20 02:04:15 roland Exp $
+ *	$Id: strace.c,v 1.66 2005/06/07 23:21:31 roland Exp $
  */
 
-#include <sys/types.h>
 #include "defs.h"
 
+#include <sys/types.h>
 #include <signal.h>
 #include <errno.h>
 #include <sys/param.h>
@@ -285,6 +285,12 @@ char *argv[];
 			break;
 		case 's':
 			max_strlen = atoi(optarg);
+			if (max_strlen < 0) {
+				fprintf(stderr,
+					"%s: invalid -s argument: %s\n",
+					progname, optarg);
+				exit(1);
+			}
 			break;
 		case 'S':
 			set_sortby(optarg);
@@ -597,6 +603,13 @@ Process %u attached - interrupt to quit\n",
 			}
 			else
 				setreuid(run_uid, run_uid);
+
+			/*
+			 * Induce an immediate stop so that the parent
+			 * will resume us with PTRACE_SYSCALL and display
+			 * this execve call normally.
+			 */
+			kill(getpid(), SIGSTOP);
 #endif /* !USE_PROCFS */
 
 			execv(pathname, &argv[optind]);
@@ -617,11 +630,6 @@ Process %u attached - interrupt to quit\n",
 				exit(1);
 			}
 #endif /* USE_PROCFS */
-#ifndef USE_PROCFS
-			if (!cflag)
-				fake_execve(tcp, pathname,
-					    &argv[optind], environ);
-#endif /* !USE_PROCFS */
 			break;
 		}
 	}
@@ -994,7 +1002,7 @@ int attaching;
 			if (tcp->status.PR_WHY == PR_SYSENTRY) {
 				tcp->flags &= ~TCB_INSYSCALL;
 				get_scno(tcp);
-				if (tcp->scno == SYS_execve)
+				if (known_scno(tcp) == SYS_execve)
 					break;
 			}
 			/* Set it running: maybe execve will be next. */
@@ -1478,7 +1486,7 @@ rebuild_pollv()
 		free (pollv);
 	pollv = (struct pollfd *) malloc(nprocs * sizeof pollv[0]);
 	if (pollv == NULL) {
-		fprintf(stderr, "strace: out of memory for poll vector\n");
+		fprintf(stderr, "%s: out of memory\n", progname);
 		exit(1);
 	}
 
@@ -2238,6 +2246,15 @@ Process %d attached (waiting for parent)\n",
 				pc += (psr >> PSR_RI) & 0x3;
 				ptrace(PT_GETSIGINFO, pid, 0, (long) &si);
 				addr = (unsigned long) si.si_addr;
+#elif defined PTRACE_GETSIGINFO
+				if (WSTOPSIG(status) == SIGSEGV ||
+				    WSTOPSIG(status) == SIGBUS) {
+					siginfo_t si;
+					if (ptrace(PTRACE_GETSIGINFO, pid,
+						   0, &si) == 0)
+						addr = (unsigned long)
+							si.si_addr;
+				}
 #endif
 				printleader(tcp);
 				tprintf("--- %s (%s) @ %lx (%lx) ---",
