@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.4 1999/11/26 09:54:08 wichert Exp $
+ *	$Id: syscallent.h,v 1.9 2001/03/27 13:57:48 hughesj Exp $
  */
 
 #ifdef MIPS
@@ -302,6 +302,11 @@
 	{ -1,	0,	printargs,		"SYS_248"	}, /* 248 */
 	{ -1,	0,	printargs,		"SYS_249"	}, /* 249 */
 	{ -1,	0,	printargs,		"SYS_250"	}, /* 250 */
+	{ -1,	0,	printargs,		"SYS_251"	}, /* 251 */
+	{ -1,	0,	printargs,		"SYS_252"	}, /* 252 */
+	{ -1,	0,	printargs,		"SYS_253"	}, /* 253 */
+	{ -1,	0,	printargs,		"SYS_254"	}, /* 254 */
+	{ -1,	0,	printargs,		"SYS_255"	}, /* 255 */
 #else /* !MIPS */
 	{ -1,	TF,	sys_lstat,		"lstat"		}, /* 88 */
 	{ -1,	TF,	sys_symlink,		"symlink"	}, /* 89 */
@@ -363,162 +368,114 @@
 #if UNIXWARE >= 2
 	{ -1,	0,	sys_seteuid,		"seteuid"	}, /* 141 */
 	{ -1,	0, 	printargs,		"SYS_142"	}, /* 142 */
-	{ -1,	0,	printargs,		"keyctl"	}, /* 143 */
-	{ -1,	0,	printargs,		"secsys"	}, /* 144 */
-	{ -1,	0,	printargs,		"filepriv"	}, /* 145 */
-	{ -1,	0,	printargs,		"procpriv"	}, /* 146 */
-	{ -1,	0,	printargs,		"devstat"	}, /* 147 */
+	{ -1,	0,	sys_keyctl,		"keyctl"	}, /* 143 */
+	{ -1,	0,	sys_secsys,		"secsys"	}, /* 144 */
+	{ -1,	0,	sys_filepriv,		"filepriv"	}, /* 145 */
+	{ -1,	0,	sys_procpriv,		"procpriv"	}, /* 146 */
+	{ -1,	0,	sys_devstat,		"devstat"	}, /* 147 */
 	{ -1,	0,	sys_aclipc,		"aclipc"	}, /* 148 */
-	{ -1,	0,	printargs,		"fdevstat"	}, /* 149 */
-	{ -1,	0,	printargs,		"flvlfile"	}, /* 150 */
-	{ -1,	0,	printargs,		"lvlfile"	}, /* 151 */
+	{ -1,	0,	sys_fdevstat,		"fdevstat"	}, /* 149 */
+	{ -1,	0,	sys_flvlfile,		"flvlfile"	}, /* 150 */
+	{ -1,	0,	sys_lvlfile,		"lvlfile"	}, /* 151 */
 	{ -1,	0, 	printargs,		"SYS_152"	}, /* 152 */
-	{ -1,	0,	printargs,		"lvlequal"	}, /* 153 */
-	{ -1,	0,	printargs,		"lvlproc"	}, /* 154 */
+	{ -1,	0,	sys_lvlequal,		"lvlequal"	}, /* 153 */
+	{ -1,	0,	sys_lvlproc,		"lvlproc"	}, /* 154 */
 	{ -1,	0, 	printargs,		"SYS_155"	}, /* 155 */
-	{ -1,	0,	printargs,		"lvlipc"	}, /* 156 */
+	{ -1,	0,	sys_lvlipc,		"lvlipc"	}, /* 156 */
 	{ -1,	0,	sys_acl,		"acl"		}, /* 157 */
-	{ -1,	0,	printargs,		"auditevt"	}, /* 158 */
-	{ -1,	0,	printargs,		"auditctl"	}, /* 159 */
-	{ -1,	0,	printargs,		"auditdmp"	}, /* 160 */
-	{ -1,	0,	printargs,		"auditlog"	}, /* 161 */
-	{ -1,	0,	printargs,		"auditbuf"	}, /* 162 */
-	{ -1,	0,	printargs,		"lvldom"	}, /* 163 */
-	{ -1,	0,	printargs,		"lvlvfs"	}, /* 164 */
-	{ -1,	0,	printargs,		"mkmld"		}, /* 165 */
-	{ -1,	0,	printargs,		"mldmode"	}, /* 166 */
-	{ -1,	0,	printargs,		"secadvise"	}, /* 167 */
-	{ -1,	0,	printargs,		"online"	}, /* 168 */
+	{ -1,	0,	sys_auditevt,		"auditevt"	}, /* 158 */
+	{ -1,	0,	sys_auditctl,		"auditctl"	}, /* 159 */
+	{ -1,	0,	sys_auditdmp,		"auditdmp"	}, /* 160 */
+	{ -1,	0,	sys_auditlog,		"auditlog"	}, /* 161 */
+	{ -1,	0,	sys_auditbuf,		"auditbuf"	}, /* 162 */
+	{ -1,	0,	sys_lvldom,		"lvldom"	}, /* 163 */
+	{ -1,	0,	sys_lvlvfs,		"lvlvfs"	}, /* 164 */
+	{ -1,	0,	sys_mkmld,		"mkmld"		}, /* 165 */
+	{ -1,	0,	sys_mldmode,		"mldmode"	}, /* 166 */
+	{ -1,	0,	sys_secadvise,		"secadvise"	}, /* 167 */
+	{ -1,	0,	sys_online,		"online"	}, /* 168 */
 	{ -1,	0,	sys_setitimer,		"setitimer"	}, /* 169 */
 	{ -1,	0,	sys_getitimer,		"getitimer"	}, /* 170 */
 	{ -1,	0,	sys_gettimeofday,	"gettimeofday"	}, /* 171 */
-	{ -1,	0,	printargs,		"settimeofday"	}, /* 172 */
+	{ -1,	0,	sys_settimeofday,	"settimeofday"	}, /* 172 */
 	{ -1,	0,	sys_lwp_create,		"lwpcreate"	}, /* 173 */
 	{ -1,	0,	sys_lwp_exit,		"lwpexit"	}, /* 174 */
 	{ -1,	0,	sys_lwp_wait,		"lwpwait"	}, /* 175 */
 	{ -1,	0,	sys_lwp_self,		"lwpself"	}, /* 176 */
-	{ -1,	0,	printargs,		"lwpinfo"	}, /* 177 */
-	{ -1,	0,	printargs,		"lwpprivate"	}, /* 178 */
+	{ -1,	0,	sys_lwpinfo,		"lwpinfo"	}, /* 177 */
+	{ -1,	0,	sys_lwpprivate,		"lwpprivate"	}, /* 178 */
 	{ -1,	0,	sys_processor_bind,	"processor_bind"}, /* 179 */
-	{ -1,	0,	printargs,		"processor_exbind"}, /* 180 */
+	{ -1,	0,	sys_processor_exbind,	"processor_exbind"}, /* 180 */
 	{ -1,	0, 	printargs,		"SYS_181"	}, /* 181 */
 	{ -1,	0, 	printargs,		"SYS_182"	}, /* 182 */
-	{ -1,	0,	printargs,		"prepblock"	}, /* 183 */
-	{ -1,	0,	printargs,		"block"		}, /* 184 */
-	{ -1,	0,	printargs,		"rdblock"	}, /* 185 */
-	{ -1,	0,	printargs,		"unblock"	}, /* 186 */
-	{ -1,	0,	printargs,		"cancelblock"	}, /* 187 */
+	{ -1,	0,	sys_prepblock,		"prepblock"	}, /* 183 */
+	{ -1,	0,	sys_block,		"block"		}, /* 184 */
+	{ -1,	0,	sys_rdblock,		"rdblock"	}, /* 185 */
+	{ -1,	0,	sys_unblock,		"unblock"	}, /* 186 */
+	{ -1,	0,	sys_cancelblock,	"cancelblock"	}, /* 187 */
 	{ -1,	0, 	printargs,		"SYS_188"	}, /* 188 */
-	{ -1,	0,	sys_pread,		"pread"		}, /* 189 */
-	{ -1,	0,	sys_pwrite,		"pwrite"	}, /* 190 */
-	{ -1,	0,	printargs,		"truncate"	}, /* 191 */
-	{ -1,	0,	printargs,		"ftruncate"	}, /* 192 */
-	{ -1,	0,	printargs,		"lwpkill"	}, /* 193 */
-	{ -1,	0,	printargs,		"sigwait"	}, /* 194 */
-	{ -1,	0,	printargs,		"fork1"		}, /* 195 */
-	{ -1,	0,	printargs,		"forkall"	}, /* 196 */
-	{ -1,	0,	printargs,		"modload"	}, /* 197 */
-	{ -1,	0,	printargs,		"moduload"	}, /* 198 */
-	{ -1,	0,	printargs,		"modpath"	}, /* 199 */
-	{ -1,	0,	printargs,		"modstat"	}, /* 200 */
-	{ -1,	0,	printargs,		"modadm"	}, /* 201 */
-	{ -1,	0,	printargs,		"getksym"	}, /* 202 */
-	{ -1,	0,	printargs,		"lwpsuspend"	}, /* 203 */
-	{ -1,	0,	printargs,		"lwpcontinue"	}, /* 204 */
-	{ -1,	0,	printargs,		"priocntllst"	}, /* 205 */
-	{ -1,	0,	printargs,		"sleep"		}, /* 206 */
-	{ -1,	0,	printargs,		"lwp_sema_wait"	}, /* 207 */
-	{ -1,	0,	printargs,		"lwp_sema_post"	}, /* 208 */
-	{ -1,	0,	printargs,		"lwp_sema_trywait"}, /* 209 */
-#else
-	{ -1,	0,	sys_seteuid,		"seteuid"	}, /* 141 */
-	{ -1,	0,	sys_vtrace,		"vtrace"	}, /* 142 */
-	{ -1,	TP,	sys_fork1,		"fork1"		}, /* 143 */
-	{ -1,	TS,	sys_sigtimedwait,	"sigtimedwait"	}, /* 144 */
-	{ -1,	0,	sys_lwp_info,		"lwp_info"	}, /* 145 */
-	{ -1,	0,	sys_yield,		"yield"		}, /* 146 */
-	{ -1,	0,	sys_lwp_sema_wait,	"lwp_sema_wait"	}, /* 147 */
-	{ -1,	0,	sys_lwp_sema_post,	"lwp_sema_post"	}, /* 148 */
-	{ -1,	0,	printargs,		"SYS_149"	}, /* 149 */
-	{ -1,	0,	printargs,		"SYS_150"	}, /* 150 */
-	{ -1,	0,	printargs,		"SYS_151"	}, /* 151 */
-	{ -1,	0,	sys_modctl,		"modctl"	}, /* 152 */
-	{ -1,	0,	sys_fchroot,		"fchroot"	}, /* 153 */
-	{ -1,	TF,	sys_utimes,		"utimes"	}, /* 154 */
-	{ -1,	0,	sys_vhangup,		"vhangup"	}, /* 155 */
-	{ -1,	0,	sys_gettimeofday,	"gettimeofday"	}, /* 156 */
-	{ -1,	0,	sys_getitimer,		"getitimer"	}, /* 157 */
-	{ -1,	0,	sys_setitimer,		"setitimer"	}, /* 158 */
-	{ -1,	0,	sys_lwp_create,		"lwp_create"	}, /* 159 */
-	{ -1,	0,	sys_lwp_exit,		"lwp_exit"	}, /* 160 */
-	{ -1,	0,	sys_lwp_suspend,	"lwp_suspend"	}, /* 161 */
-	{ -1,	0,	sys_lwp_continue,	"lwp_continue"	}, /* 162 */
-	{ -1,	0,	sys_lwp_kill,		"lwp_kill"	}, /* 163 */
-	{ -1,	0,	sys_lwp_self,		"lwp_self"	}, /* 164 */
-	{ -1,	0,	sys_lwp_setprivate,	"lwp_setprivate"}, /* 165 */
-	{ -1,	0,	sys_lwp_getprivate,	"lwp_getprivate"}, /* 166 */
-	{ -1,	0,	sys_lwp_wait,		"lwp_wait"	}, /* 167 */
-	{ -1,	0,	sys_lwp_mutex_unlock,	"lwp_mutex_unlock"}, /* 168 */
-	{ -1,	0,	sys_lwp_mutex_lock,	"lwp_mutex_lock"}, /* 169 */
-	{ -1,	0,	sys_lwp_cond_wait,	"lwp_cond_wait"}, /* 170 */
-	{ -1,	0,	sys_lwp_cond_signal,	"lwp_cond_signal"}, /* 171 */
-	{ -1,	0,	sys_lwp_cond_broadcast,	"lwp_cond_broadcast"}, /* 172 */
-	{ -1,	0,	sys_pread,		"pread"		}, /* 173 */
-	{ -1,	0,	sys_pwrite,		"pwrite"	}, /* 174 */
-	{ -1,	0,	sys_llseek,		"llseek"	}, /* 175 */
-	{ -1,	0,	sys_inst_sync,		"inst_sync"	}, /* 176 */
-	{ -1,	0,	printargs,		"SYS_177"	}, /* 177 */
-	{ -1,	0,	printargs,		"SYS_178"	}, /* 178 */
-	{ -1,	0,	printargs,		"SYS_179"	}, /* 179 */
-	{ -1,	0,	printargs,		"SYS_180"	}, /* 180 */
-	{ -1,	0,	printargs,		"SYS_181"	}, /* 181 */
-	{ -1,	0,	printargs,		"SYS_182"	}, /* 182 */
-	{ -1,	0,	printargs,		"SYS_183"	}, /* 183 */
-	{ -1,	0,	printargs,		"SYS_184"	}, /* 184 */
-#ifdef HAVE_SYS_ACL_H
-	{ -1,	TF,	sys_acl,		"acl"		}, /* 185 */
-#else
-	{ -1,	0,	printargs,		"SYS_185"	}, /* 185 */
-#endif
-	{ -1,	0,	sys_auditsys,		"auditsys"	}, /* 186 */
-	{ -1,	0,	sys_processor_bind,	"processor_bind"}, /* 187 */
-	{ -1,	0,	sys_processor_info,	"processor_info"}, /* 188 */
-	{ -1,	0,	sys_p_online,		"p_online"	}, /* 189 */
-	{ -1,	0,	sys_sigqueue,		"sigqueue"	}, /* 190 */
-	{ -1,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 191 */
-	{ -1,	0,	sys_clock_settime,	"clock_settime"	}, /* 192 */
-	{ -1,	0,	sys_clock_getres,	"clock_getres"	}, /* 193 */
-	{ -1,	0,	sys_timer_create,	"timer_create"	}, /* 194 */
-	{ -1,	0,	sys_timer_delete,	"timer_delete"	}, /* 195 */
-	{ -1,	0,	sys_timer_settime,	"timer_settime"	}, /* 196 */
-	{ -1,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 197 */
-	{ -1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 198 */
-	{ -1,	0,	sys_nanosleep,		"nanosleep"	}, /* 199 */
-#ifdef HAVE_SYS_ACL_H
-	{ -1,	0,	sys_facl,		"facl"		}, /* 200 */
-#else
-	{ -1,	0,	printargs,		"SYS_200"	}, /* 200 */
-#endif
-#ifdef HAVE_SYS_DOOR_H
-	{ -1,	0,	sys_door,		"door"		}, /* 201 */
-#else
-	{ -1,	0,	printargs,		"SYS_201"	}, /* 201 */
-#endif
-	{ -1,	0,	sys_setreuid,		"setreuid"	}, /* 202 */
-	{ -1,	0,	sys_setregid,		"setregid"	}, /* 203 */
-	{ -1,	0,	printargs,		"SYS_204"	}, /* 204 */
-	{ -1,	0,	printargs,		"SYS_205"	}, /* 205 */
-	{ -1,	0,	printargs,		"SYS_206"	}, /* 206 */
-	{ -1,	0,	printargs,		"SYS_207"	}, /* 207 */
-	{ -1,	0,	printargs,		"SYS_208"	}, /* 208 */
-	{ -1,	0,	printargs,		"SYS_209"	}, /* 209 */
-#endif
+	{ -1,	TF,	sys_pread,		"pread"		}, /* 189 */
+	{ -1,	TF,	sys_pwrite,		"pwrite"	}, /* 190 */
+	{ -1,	TF,	sys_truncate,		"truncate"	}, /* 191 */
+	{ -1,	TF,	sys_ftruncate,		"ftruncate"	}, /* 192 */
+	{ -1,	0,	sys_lwpkill,		"lwpkill"	}, /* 193 */
+	{ -1,	0,	sys_sigwait,		"sigwait"	}, /* 194 */
+	{ -1,	0,	sys_fork1,		"fork1"		}, /* 195 */
+	{ -1,	0,	sys_forkall,		"forkall"	}, /* 196 */
+	{ -1,	0,	sys_modload,		"modload"	}, /* 197 */
+	{ -1,	0,	sys_moduload,		"moduload"	}, /* 198 */
+	{ -1,	0,	sys_modpath,		"modpath"	}, /* 199 */
+	{ -1,	0,	sys_modstat,		"modstat"	}, /* 200 */
+	{ -1,	0,	sys_modadm,		"modadm"	}, /* 201 */
+	{ -1,	0,	sys_getksym,		"getksym"	}, /* 202 */
+	{ -1,	0,	sys_lwpsuspend,		"lwpsuspend"	}, /* 203 */
+	{ -1,	0,	sys_lwpcontinue,	"lwpcontinue"	}, /* 204 */
+	{ -1,	0,	sys_priocntllst,	"priocntllst"	}, /* 205 */
+	{ -1,	0,	sys_sleep,		"sleep"		}, /* 206 */
+	{ -1,	0,	sys_lwp_sema_wait,	"lwp_sema_wait"	}, /* 207 */
+	{ -1,	0,	sys_lwp_sema_post,	"lwp_sema_post"	}, /* 208 */
+	{ -1,	0,	sys_lwp_sema_trywait,	"lwp_sema_trywait"}, /* 209 */
 	{ -1,	0,	printargs,		"SYS_210"	}, /* 210 */
 	{ -1,	0,	printargs,		"SYS_211"	}, /* 211 */
 	{ -1,	0,	printargs,		"SYS_212"	}, /* 212 */
 	{ -1,	0,	printargs,		"SYS_213"	}, /* 213 */
 	{ -1,	0,	printargs,		"SYS_214"	}, /* 214 */
 	{ -1,	0,	printargs,		"SYS_215"	}, /* 215 */
+#if UNIXWARE >= 7
+	{ -1,	TF,	sys_fstatvfs64,		"fstatvfs64"	}, /* 216 */
+	{ -1,	TF,	sys_statvfs64,		"statvfs64"	}, /* 217 */
+	{ -1,	TF,	sys_ftruncate64,	"ftruncate64"	}, /* 218 */
+	{ -1,	TF,	sys_truncate64,		"truncate64"	}, /* 219 */
+	{ -1,	0,	sys_getrlimit64,	"getrlimit64"	}, /* 220 */
+	{ -1,	0,	sys_setrlimit64,	"setrlimit64"	}, /* 221 */
+	{ -1,	TF,	sys_lseek64,		"lseek64"	}, /* 222 */
+	{ -1,	TF,	sys_mmap64,		"mmap64"	}, /* 223 */
+	{ -1,	TF,	sys_pread64,		"pread64"	}, /* 224 */
+	{ -1,	TF,	sys_pwrite64,		"pwrite64"	}, /* 225 */
+	{ -1,	TF,	sys_creat64,		"creat64"	}, /* 226 */
+	{ -1,	0,	sys_dshmsys,		"dshmsys"	}, /* 227 */
+	{ -1,	0,	sys_invlpg,		"invlpg"	}, /* 228 */
+	{ -1,	0,	sys_rfork1,		"rfork1"	}, /* 229 */
+	{ -1,	0,	sys_rforkall,		"rforkall"	}, /* 230 */
+	{ -1,	0,	sys_rexecve,		"rexecve"	}, /* 231 */
+	{ -1,	0,	sys_migrate,		"migrate"	}, /* 232 */
+	{ -1,	0,	sys_kill3,		"kill3"		}, /* 233 */
+	{ -1,	0,	sys_ssisys,		"ssisys"	}, /* 234 */
+	{ -1,	TN,	sys_xaccept,		"xaccept"	}, /* 235 */
+	{ -1,	TN,	sys_xbind,		"xbind"		}, /* 236 */
+	{ -1,	TN,	sys_xbindresvport,	"xbindresvport"	}, /* 237 */
+	{ -1,	TN,	sys_xconnect,		"xconnect"	}, /* 238 */
+	{ -1,	TN,	sys_xgetsockaddr,	"xgetsockaddr"	}, /* 239 */
+	{ -1,	TN,	sys_xgetsockopt,	"xgetsockopt"	}, /* 240 */
+	{ -1,	TN,	sys_xlisten,		"xlisten"	}, /* 241 */
+	{ -1,	TN,	sys_xrecvmsg,		"xrecvmsg"	}, /* 242 */
+	{ -1,	TN,	sys_xsendmsg,		"xsendmsg"	}, /* 243 */
+	{ -1,	TN,	sys_xsetsockaddr,	"xsetsockaddr"	}, /* 244 */
+	{ -1,	TN,	sys_xsetsockopt,	"xsetsockopt"	}, /* 245 */
+	{ -1,	TN,	sys_xshutdown,		"xshutdown"	}, /* 246 */
+	{ -1,	TN,	sys_xsocket,		"xsocket"	}, /* 247 */
+	{ -1,	TN,	sys_xsocketpair,	"xsocketpair"	}, /* 248 */
+#else	/* UNIXWARE 2 */
 	{ -1,	0,	printargs,		"SYS_216"	}, /* 216 */
 	{ -1,	0,	printargs,		"SYS_217"	}, /* 217 */
 	{ -1,	0,	printargs,		"SYS_218"	}, /* 218 */
@@ -552,14 +509,144 @@
 	{ -1,	0,	printargs,		"SYS_246"	}, /* 246 */
 	{ -1,	0,	printargs,		"SYS_247"	}, /* 247 */
 	{ -1,	0,	printargs,		"SYS_248"	}, /* 248 */
+#endif	/* UNIXWARE 2 */
 	{ -1,	0,	printargs,		"SYS_249"	}, /* 249 */
 	{ -1,	0,	printargs,		"SYS_250"	}, /* 250 */
-#endif /* !MIPS */
 	{ -1,	0,	printargs,		"SYS_251"	}, /* 251 */
 	{ -1,	0,	printargs,		"SYS_252"	}, /* 252 */
 	{ -1,	0,	printargs,		"SYS_253"	}, /* 253 */
 	{ -1,	0,	printargs,		"SYS_254"	}, /* 254 */
 	{ -1,	0,	printargs,		"SYS_255"	}, /* 255 */
+#else   /* !UNIXWARE */
+	{ -1,	0,	sys_seteuid,		"seteuid"	}, /* 141 */
+	{ -1,	0,	sys_vtrace,		"vtrace"	}, /* 142 */
+	{ -1,	TP,	sys_fork1,		"fork1"		}, /* 143 */
+	{ -1,	TS,	sys_sigtimedwait,	"sigtimedwait"	}, /* 144 */
+	{ -1,	0,	sys_lwp_info,		"lwp_info"	}, /* 145 */
+	{ -1,	0,	sys_yield,		"yield"		}, /* 146 */
+	{ -1,	0,	sys_lwp_sema_wait,	"lwp_sema_wait"	}, /* 147 */
+	{ -1,	0,	sys_lwp_sema_post,	"lwp_sema_post"	}, /* 148 */
+	{ -1,	0,	sys_lwp_sema_trywait,"lwp_sema_trywait"	}, /* 149 */
+	{ -1,	0,	printargs,		"SYS_150"	}, /* 150 */
+	{ -1,	0,	printargs,		"SYS_151"	}, /* 151 */
+	{ -1,	0,	sys_modctl,		"modctl"	}, /* 152 */
+	{ -1,	0,	sys_fchroot,		"fchroot"	}, /* 153 */
+	{ -1,	TF,	sys_utimes,		"utimes"	}, /* 154 */
+	{ -1,	0,	sys_vhangup,		"vhangup"	}, /* 155 */
+	{ -1,	0,	sys_gettimeofday,	"gettimeofday"	}, /* 156 */
+	{ -1,	0,	sys_getitimer,		"getitimer"	}, /* 157 */
+	{ -1,	0,	sys_setitimer,		"setitimer"	}, /* 158 */
+	{ -1,	0,	sys_lwp_create,		"lwp_create"	}, /* 159 */
+	{ -1,	0,	sys_lwp_exit,		"lwp_exit"	}, /* 160 */
+	{ -1,	0,	sys_lwp_suspend,	"lwp_suspend"	}, /* 161 */
+	{ -1,	0,	sys_lwp_continue,	"lwp_continue"	}, /* 162 */
+	{ -1,	0,	sys_lwp_kill,		"lwp_kill"	}, /* 163 */
+	{ -1,	0,	sys_lwp_self,		"lwp_self"	}, /* 164 */
+	{ -1,	0,	sys_lwp_setprivate,	"lwp_setprivate"}, /* 165 */
+	{ -1,	0,	sys_lwp_getprivate,	"lwp_getprivate"}, /* 166 */
+	{ -1,	0,	sys_lwp_wait,		"lwp_wait"	}, /* 167 */
+	{ -1,	0,	sys_lwp_mutex_unlock,	"lwp_mutex_unlock"}, /* 168 */
+	{ -1,	0,	sys_lwp_mutex_lock,	"lwp_mutex_lock"}, /* 169 */
+	{ -1,	0,	sys_lwp_cond_wait,	"lwp_cond_wait"}, /* 170 */
+	{ -1,	0,	sys_lwp_cond_signal,	"lwp_cond_signal"}, /* 171 */
+	{ -1,	0,	sys_lwp_cond_broadcast,	"lwp_cond_broadcast"}, /* 172 */
+	{ -1,	TF,	sys_pread,		"pread"		}, /* 173 */
+	{ -1,	TF,	sys_pwrite,		"pwrite"	}, /* 174 */
+	{ -1,	0,	sys_llseek,		"llseek"	}, /* 175 */
+	{ -1,	0,	sys_inst_sync,		"inst_sync"	}, /* 176 */
+	{ -1,	0,	printargs,		"srmlimitsys"	}, /* 177 */
+	{ -1,	0,	sys_kaio,		"kaio"		}, /* 178 */
+	{ -1,	0,	printargs,		"cpc"		}, /* 179 */
+	{ -1,	0,	printargs,		"SYS_180"	}, /* 180 */
+	{ -1,	0,	printargs,		"SYS_181"	}, /* 181 */
+	{ -1,	0,	printargs,		"SYS_182"	}, /* 182 */
+	{ -1,	0,	printargs,		"SYS_183"	}, /* 183 */
+	{ -1,	0,	sys_tsolsys,		"tsolsys"	}, /* 184 */
+#ifdef HAVE_SYS_ACL_H
+	{ -1,	TF,	sys_acl,		"acl"		}, /* 185 */
+#else
+	{ -1,	0,	printargs,		"SYS_185"	}, /* 185 */
+#endif
+	{ -1,	0,	sys_auditsys,		"auditsys"	}, /* 186 */
+	{ -1,	0,	sys_processor_bind,	"processor_bind"}, /* 187 */
+	{ -1,	0,	sys_processor_info,	"processor_info"}, /* 188 */
+	{ -1,	0,	sys_p_online,		"p_online"	}, /* 189 */
+	{ -1,	0,	sys_sigqueue,		"sigqueue"	}, /* 190 */
+	{ -1,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 191 */
+	{ -1,	0,	sys_clock_settime,	"clock_settime"	}, /* 192 */
+	{ -1,	0,	sys_clock_getres,	"clock_getres"	}, /* 193 */
+	{ -1,	0,	sys_timer_create,	"timer_create"	}, /* 194 */
+	{ -1,	0,	sys_timer_delete,	"timer_delete"	}, /* 195 */
+	{ -1,	0,	sys_timer_settime,	"timer_settime"	}, /* 196 */
+	{ -1,	0,	sys_timer_gettime,	"timer_gettime"	}, /* 197 */
+	{ -1,	0,	sys_timer_getoverrun,	"timer_getoverrun"}, /* 198 */
+	{ -1,	0,	sys_nanosleep,		"nanosleep"	}, /* 199 */
+#ifdef HAVE_SYS_ACL_H
+	{ -1,	0,	sys_facl,		"facl"		}, /* 200 */
+#else
+	{ -1,	0,	printargs,		"SYS_200"	}, /* 200 */
+#endif
+#ifdef HAVE_SYS_DOOR_H
+	{ -1,	0,	sys_door,		"door"		}, /* 201 */
+#else
+	{ -1,	0,	printargs,		"SYS_201"	}, /* 201 */
+#endif
+	{ -1,	0,	sys_setreuid,		"setreuid"	}, /* 202 */
+	{ -1,	0,	sys_setregid,		"setregid"	}, /* 203 */
+	{ -1,	0,	sys_install_utrap,	"install_utrap"	}, /* 204 */
+	{ -1,	0,	sys_signotify,		"signotify"	}, /* 205 */
+	{ -1,	0,	sys_schedctl,		"schedctl"	}, /* 206 */
+	{ -1,	0,	sys_pset,		"pset"	}, /* 207 */
+	{ -1,	0,	printargs,		"__sparc_utrap_install"	}, /* 208 */
+	{ -1,	0,	sys_resolvepath,	"resolvepath"	}, /* 209 */
+	{ -1,	0,	sys_signotifywait,	"signotifywait"	}, /* 210 */
+	{ -1,	0,	sys_lwp_sigredirect,	"lwp_sigredirect"	}, /* 211 */
+	{ -1,	0,	sys_lwp_alarm,		"lwp_alarm"	}, /* 212 */
+	{ -1,	0,	sys_getdents64,		"getdents64"	}, /* 213 */
+	{ -1,	0,	sys_mmap64,		"mmap64"	}, /* 214 */
+	{ -1,	0,	sys_stat64,		"stat64"	}, /* 215 */
+	{ -1,	0,	sys_lstat64,		"lstat64"	}, /* 216 */
+	{ -1,	0,	sys_fstat64,		"fstat64"	}, /* 217 */
+	{ -1,	0,	sys_statvfs64,		"statvfs64"	}, /* 218 */
+	{ -1,	0,	sys_fstatvfs64,		"fstatvfs64"	}, /* 219 */
+	{ -1,	0,	sys_setrlimit64,	"setrlimit64"	}, /* 220 */
+	{ -1,	0,	sys_getrlimit64,	"getrlimit64"	}, /* 221 */
+	{ -1,	0,	sys_pread64,		"pread64"	}, /* 222 */
+	{ -1,	0,	sys_pwrite64,		"pwrite64"	}, /* 223 */
+	{ -1,	0,	sys_creat64,		"creat64"	}, /* 224 */
+	{ -1,	0,	sys_open64,		"open64"	}, /* 225 */
+	{ -1,	0,	sys_rpcsys,		"rpcsys"	}, /* 226 */
+	{ -1,	0,	printargs,		"SYS_227"	}, /* 227 */
+	{ -1,	0,	printargs,		"SYS_228"	}, /* 228 */
+	{ -1,	0,	printargs,		"SYS_229"	}, /* 229 */
+	{ -1,	TN,	sys_so_socket,		"so_socket"	}, /* 230 */
+	{ -1,	TN,	sys_so_socketpair,	"so_socketpair"	}, /* 231 */
+	{ -1,	TN,	sys_bind,		"bind"		}, /* 232 */
+	{ -1,	TN,	sys_listen,		"listen"	}, /* 233 */
+	{ -1,	TN,	sys_accept,		"accept"	}, /* 234 */
+	{ -1,	TN,	sys_connect,		"connect"	}, /* 235 */
+	{ -1,	TN,	sys_shutdown,		"shutdown"	}, /* 236 */
+	{ -1,	TN,	sys_recv,		"recv"		}, /* 237 */
+	{ -1,	TN,	sys_recvfrom,		"recvfrom"	}, /* 238 */
+	{ -1,	TN,	sys_recvmsg,		"recvmsg"	}, /* 239 */
+	{ -1,	TN,	sys_send,		"send"		}, /* 240 */
+	{ -1,	TN,	sys_sendmsg,		"sendmsg"	}, /* 241 */
+	{ -1,	TN,	sys_sendto,		"sendto"	}, /* 242 */
+	{ -1,	TN,	sys_getpeername,	"getpeername"	}, /* 243 */
+	{ -1,	TN,	sys_getsockname,	"getsockname"	}, /* 244 */
+	{ -1,	TN,	sys_getsockopt,		"getsockopt"	}, /* 245 */
+	{ -1,	TN,	sys_setsockopt,		"setsockopt"	}, /* 246 */
+	{ -1,	TN,	sys_sockconfig,		"sockconfig"	}, /* 247 */
+	{ -1,	0,	sys_ntp_gettime,	"ntp_gettime"	}, /* 248 */
+	{ -1,	0,	sys_ntp_adjtime,	"ntp_adjtime"	}, /* 249 */
+	{ -1,	0,	printargs,		"lwp_mutex_unlock"	}, /* 250 */
+	{ -1,	0,	printargs,		"lwp_mutex_trylock"	}, /* 251 */
+	{ -1,	0,	printargs,		"lwp_mutex_init"	}, /* 252 */
+	{ -1,	0,	printargs,		"cladm"		}, /* 253 */
+	{ -1,	0,	printargs,		"lwp_sig_timedwait"	}, /* 254 */
+	{ -1,	0,	printargs,		"umount2"	}, /* 255 */
+#endif /* !UNIXWARE */
+#endif /* !MIPS */
 	{ -1,	0,	printargs,		"SYS_256"	}, /* 256 */
 	{ -1,	0,	printargs,		"SYS_257"	}, /* 257 */
 	{ -1,	0,	printargs,		"SYS_258"	}, /* 258 */
@@ -714,3 +801,27 @@
 	{ -1,	0,	printargs,		"SYS_397"	}, /* 397 */
 	{ -1,	0,	printargs,		"SYS_398"	}, /* 398 */
 	{ -1,	0,	printargs,		"SYS_399"	}, /* 399 */
+
+#ifdef HAVE_SYS_AIO_H
+	{ -1,	TF,	sys_aioread,		"aioread"	}, /* 400 */
+	{ -1,	TF,	sys_aiowrite,		"aiowrite"	}, /* 401 */
+	{ -1,	TF,	sys_aiowait,		"aiowait"	}, /* 402 */
+	{ -1,	TF,	sys_aiocancel,		"aiocancel"	}, /* 403 */
+	{ -1,	TF,	sys_aionotify,		"aionotify"	}, /* 404 */
+	{ -1,	TF,	sys_aioinit,		"aioinit"	}, /* 405 */
+	{ -1,	TF,	sys_aiostart,		"aiostart"	}, /* 406 */
+	{ -1,	TF,	sys_aiolio,		"aiolio"	}, /* 407 */
+	{ -1,	TF,	sys_aiosuspend,		"aiosuspend"	}, /* 408 */
+	{ -1,	TF,	sys_aioerror,		"aioerror"	}, /* 409 */
+	{ -1,	TF,	sys_aioliowait,		"aioliowait"	}, /* 410 */
+	{ -1,	TF,	sys_aioaread,		"aioaread"	}, /* 411 */
+	{ -1,	TF,	sys_aioawrite,		"aioawrite"	}, /* 412 */
+	{ -1,	TF,	sys_aiolio64,		"aiolio64"	}, /* 413 */
+	{ -1,	TF,	sys_aiosuspend64,	"aiosuspend64"	}, /* 414 */
+	{ -1,	TF,	sys_aioerror64,		"aioerror64"	}, /* 415 */
+	{ -1,	TF,	sys_aioliowait64,	"aioliowait64"	}, /* 416 */
+	{ -1,	TF,	sys_aioaread64,		"aioaread64"	}, /* 417 */
+	{ -1,	TF,	sys_aioawrite64,	"aioawrite64"	}, /* 418 */
+	{ -1,	TF,	sys_aiocancel64,	"aiocancel64"	}, /* 419 */
+	{ -1,	TF,	sys_aiofsync,		"aiofsync"	}, /* 420 */ 
+#endif
