@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.72 2004/09/04 04:20:43 roland Exp $
+ *	$Id: syscall.c,v 1.79 2005/06/08 20:45:28 roland Exp $
  */
 
 #include "defs.h"
@@ -289,15 +289,15 @@ qual_syscall(s, opt, not)
 	int not;
 {
 	int i;
-	int any = 0;
+	int rc = -1;
 
 	for (i = 0; i < nsyscalls; i++) {
 		if (strcmp(s, sysent[i].sys_name) == 0) {
 			qualify_one(i, opt, not);
-			any = 1;
+			rc = 0;
 		}
 	}
-	return !any;
+	return rc;
 }
 
 static int
@@ -309,12 +309,15 @@ qual_signal(s, opt, not)
 	int i;
 	char buf[32];
 
-	if (s && *s && isdigit((unsigned char)*s)) {
-		qualify_one(atoi(s), opt, not);
-		return 1;
+  	if (s && *s && isdigit((unsigned char)*s)) {
+ 		int signo = atoi(s);
+ 		if (signo < 0 || signo >= MAX_QUALS)
+ 			return -1;
+ 		qualify_one(signo, opt, not);
+ 		return 0;
 	}
 	if (strlen(s) >= sizeof buf)
-		return 0;
+		return -1;
 	strcpy(buf, s);
 	s = buf;
 	for (i = 0; s[i]; i++)
@@ -323,10 +326,10 @@ qual_signal(s, opt, not)
 		s += 3;
 	for (i = 0; i <= NSIG; i++)
 		if (strcmp(s, signame(i) + 3) == 0) {
-			qualify_one(atoi(s), opt, not);
-			return 1;
+			qualify_one(i, opt, not);
+			return 0;
 		}
-	return 0;
+	return -1;
 }
 
 static int
@@ -345,7 +348,10 @@ qual_desc(s, opt, not)
 	int not;
 {
 	if (s && *s && isdigit((unsigned char)*s)) {
-		qualify_one(atoi(s), opt, not);
+		int desc = atoi(s);
+		if (desc < 0 || desc >= MAX_QUALS)
+			return -1;
+		qualify_one(desc, opt, not);
 		return 0;
 	}
 	return -1;
@@ -439,7 +445,7 @@ struct tcb *tcp;
 		return;
 	if (tcp->u_arg[0] < 0 || tcp->u_arg[0] >= MAX_QUALS)
 		return;
-	switch (tcp->scno + NR_SYSCALL_BASE) {
+	switch (known_scno(tcp)) {
 	case SYS_read:
 #ifdef SYS_pread64
 	case SYS_pread64:
@@ -449,9 +455,13 @@ struct tcb *tcp;
 #endif
 #ifdef SYS_recv
 	case SYS_recv:
+#elif defined SYS_sub_recv
+	case SYS_sub_recv:
 #endif
 #ifdef SYS_recvfrom
 	case SYS_recvfrom:
+#elif defined SYS_sub_recvfrom
+	case SYS_sub_recvfrom:
 #endif
 		if (qual_flags[tcp->u_arg[0]] & QUAL_READ)
 			dumpstr(tcp, tcp->u_arg[1], tcp->u_rval);
@@ -465,9 +475,13 @@ struct tcb *tcp;
 #endif
 #ifdef SYS_send
 	case SYS_send:
+#elif defined SYS_sub_send
+	case SYS_sub_send:
 #endif
 #ifdef SYS_sendto
 	case SYS_sendto:
+#elif defined SYS_sub_sendto
+	case SYS_sub_sendto:
 #endif
 		if (qual_flags[tcp->u_arg[0]] & QUAL_WRITE)
 			dumpstr(tcp, tcp->u_arg[1], tcp->u_arg[2]);
@@ -499,7 +513,7 @@ struct subcall {
   int subcalls[5];
 };
 
-const struct subcall subcalls_table[] = {
+static const struct subcall subcalls_table[] = {
   { SYS_shmsys, 5, { SYS_shmat, SYS_shmctl, SYS_shmdt, SYS_shmget, SYS_shmctl } },
 #ifdef SYS_semconfig
   { SYS_semsys, 4, { SYS___semctl, SYS_semget, SYS_semop, SYS_semconfig } },
@@ -512,7 +526,7 @@ const struct subcall subcalls_table[] = {
 
 #if !(defined(LINUX) && ( defined(ALPHA) || defined(MIPS) ))
 
-const int socket_map [] = {
+static const int socket_map [] = {
 	       /* SYS_SOCKET      */ 97,
 	       /* SYS_BIND        */ 104,
 	       /* SYS_CONNECT     */ 98,
@@ -532,7 +546,8 @@ const int socket_map [] = {
 	       /* SYS_RECVMSG     */ 113
 };
 
-void
+#if defined (SPARC) || defined (SPARC64)
+static void
 sparc_socket_decode (tcp)
 struct tcb *tcp;
 {
@@ -553,8 +568,9 @@ struct tcb *tcp;
 		addr += sizeof (arg);
 	}
 }
+#endif
 
-void
+static void
 decode_subcall(tcp, subcall, nsubcalls, style)
 struct tcb *tcp;
 int subcall;
@@ -640,7 +656,7 @@ struct tcb *tcp;
 	 * correctly support following forks in the presence of tracing
 	 * qualifiers.
 	 */
-	switch (tcp->scno + NR_SYSCALL_BASE) {
+	switch (known_scno(tcp)) {
 #ifdef SYS_fork
 	case SYS_fork:
 #endif
@@ -1251,14 +1267,26 @@ struct tcb *tcp;
 }
 
 
-int
+long
+known_scno(tcp)
+struct tcb *tcp;
+{
+	long scno = tcp->scno;
+	if (scno >= 0 && scno < nsyscalls && sysent[scno].native_scno != 0)
+		scno = sysent[scno].native_scno;
+	else
+		scno += NR_SYSCALL_BASE;
+	return scno;
+}
+
+static int
 syscall_fixup(tcp)
 struct tcb *tcp;
 {
 #ifndef USE_PROCFS
 	int pid = tcp->pid;
 #else /* USE_PROCFS */
-	int scno = tcp->scno;
+	int scno = known_scno(tcp);
 
 	if (!(tcp->flags & TCB_INSYSCALL)) {
 		if (tcp->status.PR_WHY != PR_SYSENTRY) {
@@ -1395,7 +1423,7 @@ struct tcb *tcp;
 	return 1;
 }
 
-int
+static int
 get_error(tcp)
 struct tcb *tcp;
 {
@@ -1829,7 +1857,8 @@ force_result(tcp, error, rval)
 	return 0;
 }
 
-int syscall_enter(tcp)
+static int
+syscall_enter(tcp)
 struct tcb *tcp;
 {
 #ifndef USE_PROCFS
@@ -2038,7 +2067,7 @@ struct tcb *tcp;
 		int i;
 		static int argreg[SUPPORTED_PERSONALITIES][MAX_ARGS] = {
 			{RDI,RSI,RDX,R10,R8,R9},	/* x86-64 ABI */
-			{RBX,RCX,RDX,RDX,RSI,RDI,RBP}	/* i386 ABI */
+			{RBX,RCX,RDX,RSI,RDI,RBP}	/* i386 ABI */
 		};
 
 		if (tcp->scno >= 0 && tcp->scno < nsyscalls && sysent[tcp->scno].nargs != -1)
@@ -2353,9 +2382,9 @@ strace: out of memory for call counts\n");
 	if (res != 1)
 		return res;
 
-	switch (tcp->scno + NR_SYSCALL_BASE) {
+	switch (known_scno(tcp)) {
 #ifdef LINUX
-#if !defined (ALPHA) && !defined(SPARC) && !defined(SPARC64) && !defined(MIPS) && !defined(HPPA) && !defined(X86_64)
+#if !defined (ALPHA) && !defined(SPARC) && !defined(SPARC64) && !defined(MIPS) && !defined(HPPA)
 	case SYS_socketcall:
 		decode_subcall(tcp, SYS_socket_subcall,
 			SYS_socket_nsubcalls, deref_style);
@@ -2364,7 +2393,7 @@ strace: out of memory for call counts\n");
 		decode_subcall(tcp, SYS_ipc_subcall,
 			SYS_ipc_nsubcalls, shift_style);
 		break;
-#endif /* !ALPHA && !MIPS && !SPARC && !SPARC64 && !HPPA && !X86_64 */
+#endif /* !ALPHA && !MIPS && !SPARC && !SPARC64 && !HPPA */
 #if defined (SPARC) || defined (SPARC64)
 	case SYS_socketcall:
 		sparc_socket_decode (tcp);
@@ -2513,10 +2542,10 @@ struct tcb *tcp;
 #elif defined(SH)
 	if (upeek(tcp->pid, 4*(REG_REG0+1), &val) < 0)
 		return -1;
-#endif /* SPARC || SPARC64 */
 #elif defined(IA64)
 	if (upeek(tcp->pid, PT_R9, &val) < 0)
 		return -1;
+#endif /* SPARC || SPARC64 */
 #endif /* LINUX */
 
 #ifdef SUNOS4
@@ -2652,7 +2681,7 @@ FILE *outf;
 		error_cum += counts[i].errors;
 		tv_add(&tv_cum, &tv_cum, &counts[i].time);
 	}
-	if (sortfun)
+	if (counts && sortfun)
 		qsort((void *) sorted_count, nsyscalls, sizeof(int), sortfun);
 	fprintf(outf, "%6.6s %11.11s %11.11s %9.9s %9.9s %s\n",
 		"% time", "seconds", "usecs/call",
