@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: system.c,v 1.32 2004/09/04 03:39:20 roland Exp $
+ *	$Id: system.c,v 1.37 2005/06/01 19:22:06 roland Exp $
  */
 
 #include "defs.h"
@@ -36,12 +36,23 @@
 #define _LINUX_SOCKET_H
 #define _LINUX_FS_H
 
-#define MS_RDONLY   1  /* Mount read-only */
-#define MS_NOSUID   2  /* Ignore suid and sgid bits */
-#define MS_NODEV    4  /* Disallow access to device special files */
-#define MS_NOEXEC   8  /* Disallow program execution */
-#define MS_SYNCHRONOUS 16  /* Writes are synced at once */
-#define MS_REMOUNT 32  /* Alter flags of a mounted FS */
+#define MS_RDONLY	 1	/* Mount read-only */
+#define MS_NOSUID	 2	/* Ignore suid and sgid bits */
+#define MS_NODEV	 4	/* Disallow access to device special files */
+#define MS_NOEXEC	 8	/* Disallow program execution */
+#define MS_SYNCHRONOUS	16	/* Writes are synced at once */
+#define MS_REMOUNT	32	/* Alter flags of a mounted FS */
+#define MS_MANDLOCK	64	/* Allow mandatory locks on an FS */
+#define MS_DIRSYNC	128	/* Directory modifications are synchronous */
+#define MS_NOATIME	1024	/* Do not update access times. */
+#define MS_NODIRATIME	2048	/* Do not update directory access times */
+#define MS_BIND		4096
+#define MS_MOVE		8192
+#define MS_REC		16384
+#define MS_VERBOSE	32768
+#define MS_POSIXACL	(1<<16)	/* VFS does not apply the umask */
+#define MS_ACTIVE	(1<<30)
+#define MS_NOUSER	(1<<31)
 
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -72,12 +83,18 @@ static const struct xlat mount_flags[] = {
 	{ MS_NOSUID,	"MS_NOSUID"	},
 	{ MS_NODEV,	"MS_NODEV"	},
 	{ MS_NOEXEC,	"MS_NOEXEC"	},
-#ifdef MS_SYNCHRONOUS
 	{ MS_SYNCHRONOUS,"MS_SYNCHRONOUS"},
-#else
-	{ MS_SYNC,	"MS_SYNC"	},
-#endif
 	{ MS_REMOUNT,	"MS_REMOUNT"	},
+	{ MS_MANDLOCK,	"MS_MANDLOCK"	},
+	{ MS_NOATIME,	"MS_NOATIME"	},
+	{ MS_NODIRATIME,"MS_NODIRATIME"	},
+	{ MS_BIND,	"MS_BIND"	},
+	{ MS_MOVE,	"MS_MOVE"	},
+	{ MS_REC,	"MS_REC"	},
+	{ MS_VERBOSE,	"MS_VERBOSE"	},
+	{ MS_POSIXACL,	"MS_POSIXACL"	},
+	{ MS_ACTIVE,	"MS_ACTIVE"	},
+	{ MS_NOUSER,	"MS_NOUSER"	},
 	{ 0,		NULL		},
 };
 
@@ -90,9 +107,12 @@ struct tcb *tcp;
 		tprintf(", ");
 		printpath(tcp, tcp->u_arg[1]);
 		tprintf(", ");
-		printpath(tcp, tcp->u_arg[2]);
+		if ((tcp->u_arg[3] & (MS_BIND|MS_MOVE|MS_REMOUNT)) == 0)
+			printpath(tcp, tcp->u_arg[2]);
+		else
+			tprintf("%#lx", tcp->u_arg[2]);
 		tprintf(", ");
-		printflags(mount_flags, tcp->u_arg[3]);
+		printflags(mount_flags, tcp->u_arg[3], "MS_???");
 		tprintf(", %#lx", tcp->u_arg[4]);
 	}
 	return 0;
@@ -177,14 +197,11 @@ sys_reboot(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		if (!printflags(bootflags1, tcp->u_arg[0]))
-			tprintf("LINUX_REBOOT_MAGIC???");
+		printflags(bootflags1, tcp->u_arg[0], "LINUX_REBOOT_MAGIC_???");
 		tprintf(", ");
-		if (!printflags(bootflags2, tcp->u_arg[1]))
-			tprintf("LINUX_REBOOT_MAGIC???");
+		printflags(bootflags2, tcp->u_arg[1], "LINUX_REBOOT_MAGIC_???");
 		tprintf(", ");
-		if (!printflags(bootflags3, tcp->u_arg[2]))
-			tprintf("LINUX_REBOOT_CMD_???");
+		printflags(bootflags3, tcp->u_arg[2], "LINUX_REBOOT_CMD_???");
 		if (tcp->u_arg[2] == LINUX_REBOOT_CMD_RESTART2) {
 			tprintf(", ");
 			printstr(tcp, tcp->u_arg[3], -1);
@@ -231,7 +248,7 @@ struct tcb *tcp;
 		printxval(cacheflush_scope, tcp->u_arg[1], "FLUSH_SCOPE_???");
 		tprintf(", ");
 		/* flags */
-		printflags(cacheflush_flags, tcp->u_arg[2]);
+		printflags(cacheflush_flags, tcp->u_arg[2], "FLUSH_CACHE_???");
 		/* len */
 		tprintf(", %lu", tcp->u_arg[3]);
 	}
@@ -282,8 +299,7 @@ sys_reboot(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		if (!printflags(bootflags, tcp->u_arg[0]))
-			tprintf("RB_???");
+		printflags(bootflags, tcp->u_arg[0], "RB_???");
 		if (tcp->u_arg[0] & RB_STRING) {
 			printstr(tcp, tcp->u_arg[1], -1);
 		}
@@ -381,8 +397,7 @@ struct tcb *tcp;
 		}
 		printstr(tcp, tcp->u_arg[1], -1);
 		tprintf(", ");
-		if (!printflags(mountflags, tcp->u_arg[2] & ~M_NEWTYPE))
-			tprintf("0");
+		printflags(mountflags, tcp->u_arg[2] & ~M_NEWTYPE, "M_???");
 		tprintf(", ");
 
 		if (strcmp(type, "4.2") == 0) {
@@ -402,8 +417,7 @@ struct tcb *tcp;
 			tprintf("[");
 			printsock(tcp, (int) a.addr);
 			tprintf(", ");
-			if (!printflags(nfsflags, a.flags))
-				tprintf("NFSMNT_???");
+			printflags(nfsflags, a.flags, "NFSMNT_???");
 			tprintf(", ws:%u,rs:%u,to:%u,re:%u,",
 				a.wsize, a.rsize, a.timeo, a.retrans);
 			if (a.flags & NFSMNT_HOSTNAME && a.hostname)
@@ -1196,7 +1210,7 @@ struct tcb *tcp;
 		tprintf(", ");
 		printpath(tcp, tcp->u_arg[1]);
 		tprintf(", ");
-		printflags(mount_flags, tcp->u_arg[2]);
+		printflags(mount_flags, tcp->u_arg[2], "MS_???");
 		if (tcp->u_arg[2] & (MS_FSS | MS_DATA)) {
 			tprintf(", ");
 			tprintf("%ld", tcp->u_arg[3]);
@@ -1213,8 +1227,7 @@ struct tcb *tcp;
 					tprintf("addr=");
 					printsock(tcp, (int) args.addr);
 					tprintf(", flags=");
-					if (!printflags(nfs_flags, args.flags))
-						tprintf("NFSMNT_???");
+					printflags(nfs_flags, args.flags, "NFSMNT_???");
 					tprintf(", hostname=");
 					printstr(tcp, (int) args.hostname, -1);
 					tprintf(", ...}");
@@ -1309,7 +1322,7 @@ struct tcb *tcp;
 		tprintf(", ");
 		printpath(tcp, tcp->u_arg[1]);
 		tprintf(", ");
-		printflags(mount_flags, tcp->u_arg[2]);
+		printflags(mount_flags, tcp->u_arg[2], "MS_???");
 		/* The doc sez that the file system type is given as a
 		   fsindex, and we should use sysfs to work out the name.
 		   This appears to be untrue for UW.  Maybe it's untrue
@@ -1333,8 +1346,7 @@ struct tcb *tcp;
 					tprintf("%#lx", tcp->u_arg[4]);
 				else {
 					tprintf("{ flags=");
-					if (!printflags(vxfs_flags, args.mflags))
-						tprintf("0x%08x", args.mflags);
+					printflags(vxfs_flags, args.mflags, "VX_MS_???");
 					if (args.mflags & VX_MS_SNAPSHOT) {
 						tprintf (", snapof=");
 						printstr (tcp,
@@ -1367,8 +1379,7 @@ struct tcb *tcp;
 						printsock(tcp, (int) addr.buf, addr.len);
 					}
 					tprintf(", flags=");
-					if (!printflags(nfs_flags, args.flags))
-						tprintf("NFSMNT_???");
+					printflags(nfs_flags, args.flags, "NFSMNT_???");
 					tprintf(", hostname=");
 					printstr(tcp, (int) args.hostname, -1);
 					tprintf(", ...}");
@@ -1446,14 +1457,14 @@ struct tcb *tcp;
 	if(!entering(tcp)) {
 		if (!arg0) {
 			if ((arg0 = malloc(sizeof(*arg0))) == NULL) {
-				fprintf(stderr, "sys_capget: no memory\n");
+				fprintf(stderr, "out of memory\n");
 				tprintf("%#lx, %#lx", tcp->u_arg[0], tcp->u_arg[1]);
 				return -1;
 			}
 		}
 		if (!arg1) {
 			if ((arg1 = malloc(sizeof(*arg1))) == NULL) {
-				fprintf(stderr, "sys_capget: no memory\n");
+				fprintf(stderr, "out of memory\n");
 				tprintf("%#lx, %#lx", tcp->u_arg[0], tcp->u_arg[1]);
 				return -1;
 			}
@@ -1477,11 +1488,11 @@ struct tcb *tcp;
 			tprintf("???");
 		else {
 			tprintf("{");
-			printflags(capabilities, arg1->effective);
+			printflags(capabilities, arg1->effective, "CAP_???");
 			tprintf(", ");
-			printflags(capabilities, arg1->permitted);
+			printflags(capabilities, arg1->permitted, "CAP_???");
 			tprintf(", ");
-			printflags(capabilities, arg1->inheritable);
+			printflags(capabilities, arg1->inheritable, "CAP_???");
 			tprintf("}");
 		}
 	}
@@ -1498,14 +1509,14 @@ struct tcb *tcp;
 	if(entering(tcp)) {
 		if (!arg0) {
 			if ((arg0 = malloc(sizeof(*arg0))) == NULL) {
-				fprintf(stderr, "sys_capset: no memory\n");
+				fprintf(stderr, "out of memory\n");
 				tprintf("%#lx, %#lx", tcp->u_arg[0], tcp->u_arg[1]);
 				return -1;
 			}
 		}
 		if (!arg1) {
 			if ((arg1 = malloc(sizeof(*arg1))) == NULL) {
-				fprintf(stderr, "sys_capset: no memory\n");
+				fprintf(stderr, "out of memory\n");
 				tprintf("%#lx, %#lx", tcp->u_arg[0], tcp->u_arg[1]);
 				return -1;
 			}
@@ -1529,11 +1540,11 @@ struct tcb *tcp;
 			tprintf("???");
 		else {
 			tprintf("{");
-			printflags(capabilities, arg1->effective);
+			printflags(capabilities, arg1->effective, "CAP_???");
 			tprintf(", ");
-			printflags(capabilities, arg1->permitted);
+			printflags(capabilities, arg1->permitted, "CAP_???");
 			tprintf(", ");
-			printflags(capabilities, arg1->inheritable);
+			printflags(capabilities, arg1->inheritable, "CAP_???");
 			tprintf("}");
 		}
 	}
@@ -1802,13 +1813,25 @@ struct tcb *tcp;
 {
 	struct __sysctl_args info;
 	int *name;
-	umove (tcp, tcp->u_arg[0], &info);
+	unsigned long size;
 
-	name = alloca (sizeof (int) * info.nlen);
-	umoven(tcp, (size_t) info.name, sizeof (int) * info.nlen, (char *) name);
+	if (umove (tcp, tcp->u_arg[0], &info) < 0)
+		return printargs(tcp);
+
+	size = sizeof (int) * (unsigned long) info.nlen;
+	name = (size / sizeof (int) != info.nlen) ? NULL : malloc (size);
+	if (name == NULL ||
+	    umoven(tcp, (unsigned long) info.name, size, (char *) name) < 0) {
+		free(name);
+		if (entering(tcp))
+			tprintf("{%p, %d, %p, %p, %p, %Zu}",
+				info.name, info.nlen, info.oldval,
+				info.oldlenp, info.newval, info.newlen);
+		return 0;
+	}
 
 	if (entering(tcp)) {
-		int cnt = 0;
+		int cnt = 0, max_cnt;
 
 		tprintf("{{");
 
@@ -1898,13 +1921,16 @@ struct tcb *tcp;
 			goto out;
 		}
 	out:
-		while (cnt < info.nlen)
+		max_cnt = abbrev(tcp) ? max_strlen : info.nlen;
+		while (cnt < max_cnt)
 			tprintf(", %x", name[cnt++]);
+		if (cnt < info.nlen)
+			tprintf(", ...");
 		tprintf("}, %d, ", info.nlen);
 	} else {
 		size_t oldlen;
-		umove(tcp, (size_t)info.oldlenp, &oldlen);
-		if (info.nlen >= 2
+		if (umove(tcp, (size_t)info.oldlenp, &oldlen) >= 0
+		    && info.nlen >= 2
 		    && ((name[0] == CTL_KERN
 			 && (name[1] == KERN_OSRELEASE
 			     || name[1] == KERN_OSTYPE
@@ -1930,6 +1956,8 @@ struct tcb *tcp;
 		}
 		tprintf("}");
 	}
+
+	free(name);
 	return 0;
 }
 #else
