@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.52 2004/09/04 03:39:20 roland Exp $
+ *	$Id: util.c,v 1.62 2005/06/08 20:45:28 roland Exp $
  */
 
 #include "defs.h"
@@ -148,6 +148,7 @@ static _hack_syscall5(int,_ptrace,int,__request,int,__pid,int,__addr,int,__data,
 #define MIN(a,b)		(((a) < (b)) ? (a) : (b))
 #endif
 
+#if 0
 void
 tv_tv(tv, a, b)
 struct timeval *tv;
@@ -157,6 +158,7 @@ int b;
 	tv->tv_sec = a;
 	tv->tv_usec = b;
 }
+#endif
 
 int
 tv_nz(a)
@@ -247,7 +249,7 @@ void
 printxval(xlat, val, dflt)
 const struct xlat *xlat;
 int val;
-char *dflt;
+const char *dflt;
 {
 	char *str = xlookup(xlat, val);
 
@@ -284,9 +286,10 @@ int flags;
 }
 
 int
-printflags(xlat, flags)
+printflags(xlat, flags, dflt)
 const struct xlat *xlat;
 int flags;
+const char *dflt;
 {
 	int n;
 	char *sep;
@@ -305,10 +308,23 @@ int flags;
 			n++;
 		}
 	}
-	if (flags) {
-		tprintf("%s%#x", sep, flags);
-		n++;
+
+	if (n) {
+		if (flags) {
+			tprintf("%s%#x", sep, flags);
+			n++;
+		}
+	} else {
+		if (flags) {
+			tprintf("%#x", flags);
+			if (dflt)
+				tprintf(" /* %s */", dflt);
+		} else {
+			if (dflt)
+				tprintf("0");
+		}
 	}
+
 	return n;
 }
 
@@ -344,9 +360,9 @@ unsigned long uid;
 
 static char path[MAXPATHLEN + 1];
 
-void
+static void
 string_quote(str)
-char *str;
+const char *str;
 {
 	char buf[2 * MAXPATHLEN + 1];
 	char *s;
@@ -372,7 +388,9 @@ printpath(tcp, addr)
 struct tcb *tcp;
 long addr;
 {
-	if (umovestr(tcp, addr, MAXPATHLEN, path) < 0)
+	if (addr == 0)
+		tprintf("NULL");
+	else if (umovestr(tcp, addr, MAXPATHLEN, path) < 0)
 		tprintf("%#lx", addr);
 	else
 		string_quote(path);
@@ -385,7 +403,9 @@ struct tcb *tcp;
 long addr;
 int n;
 {
-	if (umovestr(tcp, addr, n, path) < 0)
+	if (addr == 0)
+		tprintf("NULL");
+	else 	if (umovestr(tcp, addr, n, path) < 0)
 		tprintf("%#lx", addr);
 	else {
 		path[n] = '\0';
@@ -411,7 +431,7 @@ int len;
 	if (!str) {
 		if ((str = malloc(max_strlen)) == NULL
 		    || (outstr = malloc(2*max_strlen)) == NULL) {
-			fprintf(stderr, "printstr: no memory\n");
+			fprintf(stderr, "out of memory\n");
 			tprintf("%#lx", addr);
 			return;
 		}
@@ -514,15 +534,15 @@ long addr;
 {
 	struct iovec *iov;
 	int i;
+	unsigned long size;
 
-
-	if ((iov = (struct iovec *) malloc(len * sizeof *iov)) == NULL) {
-		fprintf(stderr, "dump: No memory");
+	size = sizeof(*iov) * (unsigned long) len;
+	if (size / sizeof(*iov) != len
+	    || (iov = (struct iovec *) malloc(size)) == NULL) {
+		fprintf(stderr, "out of memory\n");
 		return;
 	}
-	if (umoven(tcp, addr,
-		   len * sizeof *iov, (char *) iov) >= 0) {
-
+	if (umoven(tcp, addr, size, (char *) iov) >= 0) {
 		for (i = 0; i < len; i++) {
                         /* include the buffer number to make it easy to
                          * match up the trace with the source */
@@ -553,7 +573,7 @@ int len;
 		if (str)
 			free(str);
 		if ((str = malloc(len)) == NULL) {
-			fprintf(stderr, "dump: no memory\n");
+			fprintf(stderr, "out of memory\n");
 			return;
 		}
 		strsize = len;
@@ -958,6 +978,7 @@ long *res;
 
 #endif /* !USE_PROCFS */
 
+#if 0
 long
 getpc(tcp)
 struct tcb *tcp;
@@ -980,7 +1001,7 @@ struct tcb *tcp;
 #elif defined(POWERPC)
 	if (upeek(tcp->pid, sizeof(unsigned long)*PT_NIP, &pc) < 0)
 		return -1;
-#elif defined(M68k)
+#elif defined(M68K)
 	if (upeek(tcp->pid, 4*PT_PC, &pc) < 0)
 		return -1;
 #elif defined(ALPHA)
@@ -1035,26 +1056,43 @@ struct tcb *tcp;
 	return regs.r_eip;
 #endif /* FREEBSD */
 }
+#endif
 
 void
 printcall(tcp)
 struct tcb *tcp;
 {
+#define PRINTBADPC tprintf(sizeof(long) == 4 ? "[????????] " : \
+			   sizeof(long) == 8 ? "[????????????????] " : \
+			   NULL /* crash */)
 
 #ifdef LINUX
 #ifdef I386
 	long eip;
 
 	if (upeek(tcp->pid, 4*EIP, &eip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", eip);
+
+#elif defined(S390) || defined(S390X)
+         long psw;
+         if(upeek(tcp->pid,PT_PSWADDR,&psw) < 0) {
+                 PRINTBADPC;
+                 return;
+         }
+#ifdef S390
+         tprintf("[%08lx] ", psw);
+#elif S390X
+       tprintf("[%16lx] ", psw);
+#endif
+
 #elif defined(X86_64)
 	long rip;
 
 	if (upeek(tcp->pid, 8*RIP, &rip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%16lx] ", rip);
@@ -1062,7 +1100,7 @@ struct tcb *tcp;
 	long ip;
 
 	if (upeek(tcp->pid, PT_B0, &ip) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", ip);
@@ -1074,7 +1112,7 @@ struct tcb *tcp;
 		return;
 	}
 	tprintf("[%08lx] ", pc);
-#elif defined(M68k)
+#elif defined(M68K)
 	long pc;
 
 	if (upeek(tcp->pid, 4*PT_PC, &pc) < 0) {
@@ -1086,14 +1124,14 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, REG_PC, &pc) < 0) {
-		tprintf ("[????????] ");
+		tprintf ("[????????????????] ");
 		return;
 	}
 	tprintf("[%08lx] ", pc);
 #elif defined(SPARC) || defined(SPARC64)
 	struct regs regs;
 	if (ptrace(PTRACE_GETREGS,tcp->pid,(char *)&regs,0) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", regs.r_pc);
@@ -1125,7 +1163,7 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, REG_PC, &pc) < 0) {
-		tprintf ("[????????] ");
+		tprintf ("[????????????????] ");
 		return;
 	}
 	tprintf("[%08lx] ", pc);
@@ -1133,7 +1171,7 @@ struct tcb *tcp;
 	long pc;
 
 	if (upeek(tcp->pid, 4*15, &pc) < 0) {
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08lx] ", pc);
@@ -1145,7 +1183,7 @@ struct tcb *tcp;
 
 	if (ptrace(PTRACE_GETREGS, tcp->pid, (char *) &regs, 0) < 0) {
 		perror("printcall: ptrace(PTRACE_GETREGS, ...)");
-		tprintf("[????????] ");
+		PRINTBADPC;
 		return;
 	}
 	tprintf("[%08x] ", regs.r_o7);
@@ -1153,7 +1191,7 @@ struct tcb *tcp;
 
 #ifdef SVR4
 	/* XXX */
-	tprintf("[????????] ");
+	PRINTBADPC;
 #endif
 
 #ifdef FREEBSD
@@ -1171,6 +1209,9 @@ struct tcb *tcp;
 #ifndef CLONE_PTRACE
 # define CLONE_PTRACE    0x00002000
 #endif
+#ifndef CLONE_STOPPED
+# define CLONE_STOPPED   0x02000000
+#endif
 
 #ifdef IA64
 
@@ -1370,7 +1411,7 @@ struct tcb *tcp;
 		return -1;
 	}
 
-	switch (tcp->scno) {
+	switch (known_scno(tcp)) {
 #ifdef SYS_vfork
 	case SYS_vfork:
 #endif
@@ -1999,7 +2040,7 @@ struct tcb *tcp;
 		return -1;
 	}
 	if ((strtab = malloc((unsigned)ld.ld_symb_size)) == NULL) {
-		fprintf(stderr, "fixvfork: out of memory\n");
+		fprintf(stderr, "out of memory\n");
 		return -1;
 	}
 	if (umoven(tcp, (int)ld.ld_symbols+(int)N_TXTADDR(hdr),
